@@ -23,14 +23,12 @@
 #include <config.h>
 #include "nautilus-metafile.h"
 
-#include "nautilus-bonobo-extensions.h"
 #include "nautilus-directory.h"
 #include "nautilus-directory.h"
 #include "nautilus-file-private.h"
 #include "nautilus-file-utilities.h"
 #include "nautilus-global-preferences.h"
 #include "nautilus-metadata.h"
-#include "nautilus-search-uri.h"
 #include "nautilus-thumbnails.h"
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-macros.h>
@@ -44,6 +42,7 @@
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <stdlib.h>
+#include <time.h>
 #include <unistd.h>
 
 #define METAFILE_XML_VERSION "1.0"
@@ -265,8 +264,8 @@ nautilus_metafile_get (const char *directory_uri)
  * We may want to consider limiting writes as well.
  */
 
-int num_reads_in_progress;
-GList *pending_reads;
+static int num_reads_in_progress;
+static GList *pending_reads;
 
 #if 0
 #define DEBUG_METADATA_IO
@@ -760,6 +759,17 @@ get_file_node (NautilusMetafile *metafile,
 	return NULL;
 }
 
+static void
+set_file_node_timestamp (xmlNode *node)
+{
+	char time_str[21];
+
+	/* 2^64 turns out to be 20 characters */
+	snprintf (time_str, 20, "%ld", time (NULL));
+	time_str [20] = '\0';
+	xmlSetProp (node, "timestamp", time_str);
+}
+
 static char *
 get_metadata_string_from_metafile (NautilusMetafile *metafile,
 				   const char *file_name,
@@ -819,8 +829,11 @@ set_metadata_string_in_metafile (NautilusMetafile *metafile,
 	/* Get or create the node. */
 	node = get_file_node (metafile, file_name, value != NULL);
 
-	/* Add or remove a property node. */
 	if (node != NULL) {
+		/* Set the timestamp */
+		set_file_node_timestamp (node);
+		
+		/* Add or remove a property node. */
 		property_node = xmlSetProp (node, key, value);
 		if (value == NULL) {
 			xmlRemoveProp (property_node);
@@ -880,6 +893,9 @@ set_metadata_list_in_metafile (NautilusMetafile *metafile,
 			xmlSetProp (child, list_subkey, p->data);
 			changed = TRUE;
 		}
+
+		/* Set the timestamp */
+		set_file_node_timestamp (node);
 	}
 
 	if (!changed) {
@@ -1398,6 +1414,8 @@ copy_file_metadata (NautilusMetafile *source_metafile,
 {
 	xmlNodePtr source_node, node, root;
 	GHashTable *hash, *changes;
+	char *source_file_uri;
+	char *destination_file_uri;
 
 	g_return_if_fail (NAUTILUS_IS_METAFILE (source_metafile));
 	g_return_if_fail (source_file_name != NULL);
@@ -1420,6 +1438,7 @@ copy_file_metadata (NautilusMetafile *source_metafile,
 			root = create_metafile_root (destination_metafile);
 			xmlAddChild (root, node);
 			xmlSetProp (node, "name", destination_file_name);
+			set_file_node_timestamp (node);
 			g_hash_table_insert (destination_metafile->details->node_hash,
 					     xmlMemStrdup (destination_file_name), node);
 		} else {
@@ -1440,9 +1459,12 @@ copy_file_metadata (NautilusMetafile *source_metafile,
 		}
 	}
 
-	/* FIXME: Do we want to copy the thumbnail here like in the
-	 * rename and remove cases?
-	 */
+	/* Copy the thumbnail for the file, if any. */
+	source_file_uri = metafile_get_file_uri (source_metafile, source_file_name);
+	destination_file_uri = metafile_get_file_uri (destination_metafile, destination_file_name);
+	nautilus_update_thumbnail_file_copied (source_file_uri, destination_file_uri);
+	g_free (source_file_uri);
+	g_free (destination_file_uri);
 }
 
 static void
@@ -1645,8 +1667,7 @@ allow_metafile (NautilusMetafile *metafile)
 	 * access inside gnome-vfs.
 	 */
 	uri = metafile->details->directory_uri;
-	if (nautilus_is_search_uri (uri)
-	    || eel_istr_has_prefix (uri, "ghelp:")
+	if (eel_istr_has_prefix (uri, "ghelp:")
 	    || eel_istr_has_prefix (uri, "gnome-help:")
 	    || eel_istr_has_prefix (uri, "help:")
 	    || eel_istr_has_prefix (uri, "info:")
