@@ -29,33 +29,13 @@
 #include <gtk/gtkwindow.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <libnautilus-private/nautilus-file.h>
-#include <libnautilus-private/nautilus-view-identifier.h>
 
 #define NAUTILUS_COMMAND_SPECIFIER "command:"
 #define NAUTILUS_DESKTOP_COMMAND_SPECIFIER "desktop-file:"
 
 typedef void (*NautilusApplicationChoiceCallback) (GnomeVFSMimeApplication	 *application,
 						   gpointer			  callback_data);
-typedef void (*NautilusComponentChoiceCallback)   (NautilusViewIdentifier 	 *identifier,
-						   gpointer		 	  callback_data);
 
-void nautilus_choose_application_for_file        (NautilusFile                      *file,
-						  GtkWindow                         *parent_window,
-						  NautilusApplicationChoiceCallback  callback,
-						  gpointer                           callback_data);
-void nautilus_cancel_choose_application_for_file (NautilusFile                      *file,
-						  NautilusComponentChoiceCallback    callback,
-						  gpointer                           callback_data);
-void nautilus_choose_component_for_file          (NautilusFile                      *file,
-						  GtkWindow                         *parent_window,
-						  NautilusComponentChoiceCallback    callback,
-						  gpointer                           callback_data);
-void nautilus_cancel_choose_component_for_file   (NautilusFile                      *file,
-						  NautilusComponentChoiceCallback    callback,
-						  gpointer                           callback_data);
-void nautilus_launch_action                      (GnomeVFSMimeAction                *action,
-                                                  NautilusFile                      *file,
-						   GtkWindow                         *parent_window);
 void nautilus_launch_application                 (GnomeVFSMimeApplication           *application,
 						  NautilusFile                      *file,
 						  GtkWindow                         *parent_window);
